@@ -20,8 +20,8 @@ datos_compras <- get_data(url_base, api_key, guid_datos)
 datos_disponibles <- list_guid(url_base, api_key)
 datos_disponibles[3]
 
-## ------------------------------------------------------------------------
-get_dimensions(url_base, api_key)
+## ----eval=FALSE----------------------------------------------------------
+#  get_dimensions(url_base, api_key)
 
 ## ------------------------------------------------------------------------
 datos_con_divisas <- get_data(url_base, api_key, "LICIT-ADJUD-POR-LOS-MINIS")
